/* This file was generated by syncqt. */
#ifndef QT_QTPDFQUICK_VERSION_H
#define QT_QTPDFQUICK_VERSION_H

#define QTPDFQUICK_VERSION_STR "6.11.2"

#define QTPDFQUICK_VERSION 0x0601102

#endif // QT_QTPDFQUICK_VERSION_H
